#!/bin/sh
#$ -N log_GS_filter
#$ -pe openmp 1
#$ -S /bin/sh
#$ -cwd
#$ -j y
#$ -q bioinf.q


## DESCRIPTION
## Bash shell script for processing of vcf genotype files generated by Genomestrip/2.0
## Run on Linux Sun Grid Engine.
## General aims:
## Generate summary data tables for assessment in R.
## Exclude events which are likely to be annomalies, based-on pre-determined criteria.
## Combine with genotype data generated by GATK HaplotypeCaller for deletions 50-200bp long.
## Annotate, summarise and prepare for upload to NCBI dbVAR.



## Preamble

uname -sa
set -ex
echo "`date +%y/%m/%d_%H:%M:%S`"
START=$(date +%s)
ls -la



## Load software

. /etc/profile.d/modules.sh
module load jre/1.7.0_25
module load gatk/3.4-0
module load vcftools/0.1.12b
module load snpeff/4.1
module load R/3.2.0



## Set variables

ref_path=../reference_data/
ref_seq=${ref_path}dm6.fa
cnv_path=../cnv_pipeline/
cnv_vcf=lhm_gs.cnvs.raw.vcf
omit_samps=accessory_data/odd_samples.list
exclude_intervals=accessory_data/lhmGS_excludeIntervals.list
hc_vars_path=../../HAPLOCALLER/filtering/largeIndels/
hc_vars=largeIndels.f1.f1.lhm_rg_HC_raw.vcf




## Import vcf from cnv pipeline ___

cp ${cnv_path}${cnv_vcf} . ; cp ${cnv_path}${cnv_vcf}.idx .


## Make folder for summary data.

mkdir summary_data




## Omit samples with excessive singletons, and CNVs in regions of uneven coverage.

GenomeAnalysisTK -R ${ref_seq} \
    -T SelectVariants -V ${cnv_vcf} \
    --exclude_sample_file ${omit_samps} \
    --excludeNonVariants \
    --excludeIntervals ${exclude_intervals} \
    --unsafe LENIENT_VCF_PROCESSING \
        -o goodS.${cnv_vcf}


rm ${cnv_vcf} ; rm ${cnv_vcf}.idx





## Make table summarising each CNV. ___

GenomeAnalysisTK -R ${ref_seq} \
    -T VariantsToTable \
        -V goodS.${cnv_vcf} \
            -F CHROM -F ID -F POS \
            -F HOM-REF -F HET -F HOM-VAR -F NO-CALL \
            -F AN -F AF -F AC \
            -F GSCNCATEGORY -F GCFRACTION \
            -F GCLENGTH \
            -F GLALTSUM -F GLHETSUM \
            -F GSCLUSTERSEP -F GSCNQUAL \
            -F GSNNONREF \
                --allowMissingData \
                    -o summary_data/goodS.${cnv_vcf%.vcf}.qc.tbl




## Make various summary tables using vcftools.

vcftools --vcf goodS.${cnv_vcf} --singletons --out summary_data/goodS.${cnv_vcf}
vcftools --vcf goodS.${cnv_vcf} --indv-freq-burden --out summary_data/goodS.${cnv_vcf}
vcftools --vcf goodS.${cnv_vcf} --relatedness --out summary_data/goodS.${cnv_vcf}




## Make list of good quality variants.

R CMD BATCH cnv_filter.R

mv Rplots.pdf plots_unfiltered_data.pdf




## FILTER VARIANTS AGAINST LIST.

GenomeAnalysisTK -R ${ref_seq} \
    -T SelectVariants \
    -V goodS.${cnv_vcf} \
    -IDs good_cnv_ids.txt \
        -o filtered.goodS.${cnv_vcf}

# rm goodS.${cnv_vcf}  ;  rm goodS.${cnv_vcf}.idx




## Make summary table for filtered CNVs.

GenomeAnalysisTK -R ${ref_seq} \
    -T VariantsToTable \
        -V  filtered.goodS.${cnv_vcf} \
            -F CHROM -F ID -F POS \
            -F HOM-REF -F HET -F HOM-VAR -F NO-CALL \
            -F AN -F AF -F AC \
            -F GSCNCATEGORY -F GCFRACTION \
            -F GCLENGTH \
            -F GLALTSUM -F GLHETSUM \
            -F GSCLUSTERSEP -F GSCNQUAL \
            -F GSNNONREF \
                --allowMissingData \
                    -o summary_data/filtered.goodS.${cnv_vcf}.qc.tbl






## Make a 'bed' format file of simple genomic positions.


## Emit relevant columns,  delete excess formatting.

cut -f 1,3,13,11 < summary_data/filtered.goodS.${cnv_vcf}.qc.tbl | sed -e '1d' -e '/NA/d' -e 's/-//g' > cols.txt


## Create end positions. Set base numbering to start at 0 (not 1), as standard for 'bed'.

awk '{OFS="\t";{print $1, $2-1, $2+$4, $3}}' cols.txt > summary_data/lhm_rg_genomstrip.bed
rm cols.txt




## vcfTools summary data generation, filtered data.

vcftools --vcf filtered.goodS.${cnv_vcf} --SNPdensity 100000 --out summary_data/filtered.goodS.${cnv_vcf}
vcftools --vcf filtered.goodS.${cnv_vcf} --singletons --out summary_data/filtered.goodS.${cnv_vcf}
vcftools --vcf filtered.goodS.${cnv_vcf} --indv-freq-burden --out summary_data/filtered.goodS.${cnv_vcf}
vcftools --vcf filtered.goodS.${cnv_vcf} --het --out summary_data/filtered.goodS.${cnv_vcf}
vcftools --vcf filtered.goodS.${cnv_vcf} --relatedness --out summary_data/filtered.goodS.${cnv_vcf}





## Plot the CNV QC summary filtered data.

R CMD BATCH cnv_checker.R
mv Rplots.pdf plots_filtered_data.pdf





## Split vcf by variant type ('Mixed' no longer exists).

grep '^#' filtered.goodS.${cnv_vcf} > filtered.head.txt
grep '^[^#]' filtered.goodS.${cnv_vcf} > filtered.body.txt

grep 'GSCNCATEGORY=DEL' filtered.body.txt > filtered.del.txt
grep 'GSCNCATEGORY=DUP' filtered.body.txt > filtered.dup.txt

cat filtered.head.txt filtered.del.txt > filtered.del.vcf
cat filtered.head.txt filtered.dup.txt > filtered.dup.vcf

rm filtered.head.txt
rm filtered.body.txt
rm filtered.del.txt
rm filtered.dup.txt



## Run GATK Variant Evaluation for stats per fly.

for i in filtered.???.vcf ; do
GenomeAnalysisTK -R ${ref_seq} \
    -T VariantEval \
    -eval ${i} \
    --evalModule CountVariants \
    --stratificationModule Sample -noEV \
    --unsafe LENIENT_VCF_PROCESSING \
        -o summary_data/${i%.vcf}.vareval.txt ; done







## Combine Genomestrip variants with indels from GATK HaplotyperCaller.

cp ${hc_vars_path}${hc_vars} .

GenomeAnalysisTK -R ${ref_seq} \
    -T CombineVariants \
    -V filtered.goodS.${cnv_vcf} \
    -V ${hc_vars} \
    --unsafe LENIENT_VCF_PROCESSING \
    --genotypemergeoption UNSORTED \
        -o filtered.goodS.${cnv_vcf%.vcf}.withLIndels.vcf

rm ${hc_vars} ; rm ${hc_vars}.idx




## Functional annotation.

java -Xmx2g -jar /home/w/wg/wg39/snpeff4_1/4.1/snpEff.jar dm6.03 \
    -classic -strict -canon \
    -csvStats summary_data/lhm.dbVAR.snpeff.stats.txt \
        filtered.goodS.${cnv_vcf%.vcf}.withLIndels.vcf > lhm_sx16.dbVAR.vcf

mv snpEff_summary.html summary_data/



## Cataloging.

grep -c "^[^#]" *.vcf > variant_counts.txt
mv variant_counts.txt summary_data/

find . -type f -exec ls -lt "{}" \;
find . -type f -exec md5sum "{}" \;



## Unload software modules.

module unload R/3.2.0
module unload snpeff/4.1
module unload vcftools/0.1.12b
module unload gatk/3.4-0
module unload jre/1.7.0_25

uname -sa
ls -la


## Now upload to NCBI dbVAR, and do some biological analyses on the data.

## Information:
## Me: wpgilks@gmail.com Twitter: @wpgilks and @gwas_lit and @genomic_pred
## Lab URL: http://www.sussex.ac.uk/lifesci/morrowlab/
## Sussex University computer cluster: http://www.sussex.ac.uk/its/services/research/highperformance
## GATK https://www.broadinstitute.org/gatk/
## vcftools http://vcftools.sourceforge.net/
## Genomestrip http://www.broadinstitute.org/software/genomestrip/

## Merging the very large, fragmented singleton CNVs would be good.
## Doing this in bash is complicated enough, and requires removal of the locus/genotype metrics.
## Only proper way is to recalibrate genomestrip on the regions, and run again.


## end stuff, some of which doesn't work.
END=$(date +%s.%N)
Duration=$(echo "$END - $START" | bc)
echo START
echo END
echo "`date +%y/%m/%d_%H:%M:%S`"
echo $Duration
echo "End of script"
exit
##
##