##
##  Start log
mylog = file("mylog_cnv_lister.txt", open = "wt")
sink(mylog, append=TRUE, type="message")
Sys.time()
sessionInfo()


## Load packages

package.list = c('tidyr', 'dplyr', 'ggplot2')
new.packages = package.list[!(package.list %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)
rm (package.list, new.packages)

library(ggplot2)
library(tidyr)
library(dplyr)


## Load data

qc.table.in = read.delim(file = "summary_data/goodS.lhm_gs.cnvs.raw.qc.tbl")

head (qc.table.in)




### Do some data normalisation stuff and calculate minor allele frequency groups.

unfiltered = qc.table.in %>%
  mutate (Mb = POS / 1e+06) %>%
  mutate (len = GCLENGTH /1000) %>%
  mutate (rt.len = sqrt(len)) %>%
  mutate (qual = GSCNQUAL / 1000) %>%
  mutate (gcount = HOM.REF + HET + HOM.VAR + NO.CALL) %>%
  mutate (g2 = HET + (2 * HOM.VAR)) %>%
  mutate (min.ac = pmin (HOM.REF, g2)) %>%
  mutate (maj.ac = pmax (HOM.REF, g2)) %>%
  mutate (MAF = min.ac / gcount) %>%
  mutate (rMAF = round(MAF, digits = 1))

head (unfiltered)



## Plot HET count across genome, point size by event length, colour by cluster separation.

gplot = ggplot (filter(unfiltered, CHROM!="chr4"), aes (Mb, HET, size = rt.len,
  colour = sqrt(GSCLUSTERSEP))) +
  geom_point() +
  theme_bw(base_size = 8) +
  labs (title = "unfilterd gs cnv dmel") +
  facet_grid(GSCNCATEGORY~CHROM, scales = "free_x", space = "free_x") +
  theme (strip.background = element_rect(colour = "white", fill = "white"))
gplot




## Reformat data as long.

plot.data = unfiltered %>%
  select (-c(AF, AN, AC, GLALTSUM, GLHETSUM, GSNNONREF, GCLENGTH, GSCNQUAL,  gcount, g2, min.ac, maj.ac, NO.CALL, len)) %>%
  gather (key = metric, value = value, -c(CHROM, ID, POS, MAF, rMAF, GSCNCATEGORY, HOM.REF, HET, HOM.VAR, Mb))



##  Plot metrics distributions grouped by type, colour by minor allele frequency.

flabs = as_labeller ( c (`DUP`="Duplication",  `MIXED`="mixed",  `DEL`="Deletion",
`GCFRACTION`="%GC",  `GSCLUSTERSEP`="Cluster sep.", `rt.len`="sqrt Length(Kb)",
    `qual`= "quality x10^3") )

plot = ggplot (plot.data, aes (value, colour = as.factor(rMAF), fill = as.factor(rMAF))) +
    geom_histogram() +
    theme_bw(base_size = 8) +
    labs(title = "unfiltered GS CNV QC") +
   guides(fill = guide_legend (title = "MAF")) +
    guides(colour  = guide_legend (title = "MAF")) +
       scale_fill_manual(values = c("0"="black", "0.1"="blue", "0.2"="green",
    "0.3"="yellow", "0.4"="orange", "0.5=red", "0.6"="purple")) +
    scale_colour_manual(values = c("0"="black", "0.1"="blue", "0.2"="green",
    "0.3"="yellow", "0.4"="orange", "0.5=red", "0.6"="purple")) +
    facet_grid(GSCNCATEGORY~metric, scales = "free", switch = "both", labeller = flabs)   +
    theme (strip.background = element_rect(colour = "white", fill = "white"),
      strip.text.y = element_text(angle=180),
      legend.position = c(.9,.9),
      legend.key.width = unit(.2, "cm"),
  legend.key.height = unit(.2, "cm"))
plot





## Filter the table by pre-assigned values.
## Hom.vars shouldn't exist due to our experimental design, or are very rare.
## Variants with HET count > 200, or type 'mixed' were shown to be artefacts using Integrated Genomics Viewer to inspect bam files.
## Filtering by quality score, cluster seperation and gc-fraction was based on distribututions, and viewing in IGV.

to.filter = unfiltered %>%
  filter (HOM.VAR == 0, HET < 200, GSCNCATEGORY != "MIXED", GSCNQUAL > 15, GSCLUSTERSEP < 17, GCFRACTION > 0.33)


## Save a list of just the CNV IDs to text file, which is used to select CNVs from the main vcf file.

write.table(to.filter[,c("ID")], "good_cnv_ids.txt", quote = F, row.names = F, col.names = F, sep = "\t")




### Closing down ____
ls()
rm(list = ls())
sessionInfo()
Sys.time()
sink()
unlink("mylog_cnv_lister.txt")
###
###